import 'package:intl/intl.dart';
import 'package:flutter/material.dart';
import 'package:syncfusion_flutter_charts/charts.dart';

void main() {
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({super.key});

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      title: 'Flutter Demo',
      theme: ThemeData(
        primarySwatch: Colors.blue,
      ),
      home: const MyHomePage(),
    );
  }
}

class MyHomePage extends StatefulWidget {
  const MyHomePage({super.key});

  @override
  State<MyHomePage> createState() => _MyHomePageState();
}

late ChartSeriesController seriesController;

class _MyHomePageState extends State<MyHomePage> {
  late List<ChartData> chartData;
  int count = 0;

  @override
  void initState() {
    chartData = [
      ChartData(DateTime(2021, 01), 0),
      ChartData(DateTime(2021, 02), 10000),
      ChartData(DateTime(2021, 03), 15000),
      ChartData(DateTime(2021, 04), 22000),
      ChartData(DateTime(2021, 05), 25000),
      ChartData(DateTime(2021, 06), 27000),
      ChartData(DateTime(2021, 07), 30000),
      ChartData(DateTime(2021, 08), 33000),
      ChartData(DateTime(2021, 09), 35000),
      ChartData(DateTime(2021, 10), 40000),
      ChartData(DateTime(2021, 11), 43000),
      ChartData(DateTime(2021, 12), 47000),
      ChartData(DateTime(2022, 01), 52000),
      ChartData(DateTime(2022, 02), 57000),
      ChartData(DateTime(2022, 03), 60000),
      ChartData(DateTime(2022, 04), 63000),
      ChartData(DateTime(2022, 05), 68000),
      ChartData(DateTime(2022, 06), 72000),
      ChartData(DateTime(2022, 07), 77000),
      ChartData(DateTime(2022, 08), 89000),
      ChartData(DateTime(2022, 09), 91700),
      ChartData(DateTime(2022, 10), 95100),
      ChartData(DateTime(2022, 11), 97800),
      ChartData(DateTime(2022, 12), 100000),
    ];
    super.initState();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(),
      body: Center(
        child: SizedBox(
          height: 320,
          child: SfCartesianChart(
            plotAreaBorderWidth: 0,
            annotations: [
              CartesianChartAnnotation(
                  widget: const Padding(
                    padding: EdgeInsets.all(8.0),
                    child: Text('89,000.00'),
                  ),
                  coordinateUnit: CoordinateUnit.point,
                  verticalAlignment: ChartAlignment.far,
                  x: DateTime(2022, 08),
                  y: 89000)
            ],
            onMarkerRender: (args) {
              if (args.pointIndex != 19) {
                args.markerHeight = 0;
                args.markerWidth = 0;
              }
            },
            primaryXAxis: DateTimeAxis(
              plotOffset: 20,
              axisLine: const AxisLine(width: 0),
              majorTickLines: const MajorTickLines(width: 0),
              majorGridLines: const MajorGridLines(width: 0),
              interval: 1,
              dateFormat: DateFormat('M yyyy'),
              labelIntersectAction: AxisLabelIntersectAction.multipleRows,
              axisLabelFormatter: (args) {
                count = args.text == '1 2021' ? 0 : count;
                if (int.parse(args.text.split(' ')[0]) % 3 == 0) {
                  count += 3;
                  return ChartAxisLabel('$count months', args.textStyle);
                } else {
                  return ChartAxisLabel('', args.textStyle);
                }
              },
            ),
            primaryYAxis: NumericAxis(
                labelFormat: '\${value}',
                numberFormat: NumberFormat.decimalPattern(),
                majorGridLines: const MajorGridLines(dashArray: [5, 3]),
                majorTickLines: const MajorTickLines(width: 0),
                axisLine: const AxisLine(width: 0),
                maximum: 125000,
                interval: 25000),
            series: [
              LineSeries<ChartData, DateTime>(
                dataSource: [
                  ChartData(DateTime(2022, 08), 89000),
                  ChartData(DateTime(2022, 08), 0),
                ],
                color: Colors.green,
                xValueMapper: (ChartData data, _) => data.x,
                yValueMapper: (ChartData data, _) => data.y,
              ),
              SplineAreaSeries<ChartData, DateTime>(
                  markerSettings: const MarkerSettings(
                      isVisible: true,
                      borderWidth: 2,
                      borderColor: Colors.green),
                  dataSource: chartData,
                  borderColor: Colors.green,
                  borderWidth: 3,
                  gradient: LinearGradient(colors: <Color>[
                    Colors.green.withOpacity(0.3),
                    Colors.green.withOpacity(0.01)
                  ], stops: const <double>[
                    0.2,
                    0.9,
                  ], begin: Alignment.topCenter, end: Alignment.bottomCenter),
                  onRendererCreated: (ChartSeriesController controller) {
                    seriesController = controller;
                  },
                  xValueMapper: (ChartData data, int index) => data.x,
                  yValueMapper: (ChartData data, int index) => data.y)
            ],
          ),
        ),
      ),
    );
  }
}

class ChartData {
  final DateTime x;
  final num y;

  ChartData(this.x, this.y);
}
